# Eight Mile

[![PyPi Version](https://img.shields.io/pypi/v/mead-layers)](https://pypi.org/project/mead-layers/) [![Actions Status](https://github.com/mead-ml/mead-layers/workflows/Unit%20Test/badge.svg)](https://github.com/mead-ml/mead-layers/actions) [![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

Layers built on PyTorch/TensorFlow for reuse in MEAD framework (or a la carte)
